pub trait LiveTranscript:
Debug
+ Send
+ Sync {
// Required method
fn replay_text(&self) -> Option<String>;
}Expand description
Live transcript projection used when a provider runtime needs replay text.
Required Methods
Sourcefn replay_text(&self) -> Option<String>
fn replay_text(&self) -> Option<String>
Returns the latest replayable transcript text, when any content exists.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".