pub fn create_backend(kind: AgentKind) -> Box<dyn AgentBackend>Expand description
Creates the backend implementation for the selected agent provider.
pub fn create_backend(kind: AgentKind) -> Box<dyn AgentBackend>Creates the backend implementation for the selected agent provider.