pub struct SessionStats {
pub added_lines: u64,
pub deleted_lines: u64,
pub input_tokens: u64,
pub output_tokens: u64,
}Expand description
Token and diff usage statistics associated with one agent session or isolated prompt.
Fields
added_lines: u64Added diff lines currently attributed to the session worktree.
deleted_lines: u64Deleted diff lines currently attributed to the session worktree.
input_tokens: u64Input/prompt tokens consumed by this session.
output_tokens: u64Output/response tokens produced by this session.
Implementations
Sourceimpl SessionStats
impl SessionStats
Sourcepub fn line_change_counts(diff: &str) -> (u64, u64)
pub fn line_change_counts(diff: &str) -> (u64, u64)
Counts added and deleted lines in one git patch while ignoring file
header markers such as +++ and ---.